==> wawa-service-api-0.0.14-20171201.121618-1-sources.jar: cn/com/wawa/service/api/dto/WawaCatcherEditDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;

/**
 * Created by gyf .
 * 2017/10/27 .
 */
public class WawaCatcherEditDto implements Serializable {

    private static final long serialVersionUID = -5176874342388706575L;

    /**
     * 娃娃机id
     */
    private Long id;

    /**
     * 娃娃机名称
     */
    private String catcherName;

    /**
     * 娃娃机上配置的价格/ 需要使用娃娃覆盖
     */
    private Long price;

    /**
     * 娃娃机排序值
     */
    private Long payload;

    /**
     * 娃娃id
     */
    private Long wawaId;

    /**
     * 娃娃图
     */
    private String indexImage;

    /**
     * 娃娃名称
     */
    private String wawaName;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCatcherName() {
        return catcherName;
    }

    public void setCatcherName(String catcherName) {
        this.catcherName = catcherName;
    }

    public Long getPrice() {
        return price;
    }

    public void setPrice(Long price) {
        this.price = price;
    }

    public Long getPayload() {
        return payload;
    }

    public void setPayload(Long payload) {
        this.payload = payload;
    }

    public Long getWawaId() {
        return wawaId;
    }

    public void setWawaId(Long wawaId) {
        this.wawaId = wawaId;
    }

    public String getIndexImage() {
        return indexImage;
    }

    public void setIndexImage(String indexImage) {
        this.indexImage = indexImage;
    }

    public String getWawaName() {
        return wawaName;
    }

    public void setWawaName(String wawaName) {
        this.wawaName = wawaName;
    }
}

==> wawa-service-api-0.0.19-20180108.055856-20-sources.jar: cn/com/wawa/service/api/dto/WawaCatcherEditDto.java <==
package cn.com.wawa.service.api.dto;

import java.io.Serializable;

/**
 * Created by gyf .
 * 2017/10/27 .
 */
public class WawaCatcherEditDto implements Serializable {

    private static final long serialVersionUID = -5176874342388706575L;

    /**
     * 娃娃机id
     */
    private Long id;

    /**
     * 娃娃机名称
     */
    private String catcherName;

    /**
     * 娃娃机上配置的价格/ 需要使用娃娃覆盖
     */
    private Long price;

    /**
     * 娃娃机排序值
     */
    private Long payload;

    /**
     * 娃娃id
     */
    private Long wawaId;

    /**
     * 娃娃图
     */
    private String indexImage;

    /**
     * 娃娃名称
     */
    private String wawaName;

    private String remark;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCatcherName() {
        return catcherName;
    }

    public void setCatcherName(String catcherName) {
        this.catcherName = catcherName;
    }

    public Long getPrice() {
        return price;
    }

    public void setPrice(Long price) {
        this.price = price;
    }

    public Long getPayload() {
        return payload;
    }

    public void setPayload(Long payload) {
        this.payload = payload;
    }

    public Long getWawaId() {
        return wawaId;
    }

    public void setWawaId(Long wawaId) {
        this.wawaId = wawaId;
    }

    public String getIndexImage() {
        return indexImage;
    }

    public void setIndexImage(String indexImage) {
        this.indexImage = indexImage;
    }

    public String getWawaName() {
        return wawaName;
    }

    public void setWawaName(String wawaName) {
        this.wawaName = wawaName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}
